#ifndef SUSI_LIBRARY
#define SUSI_LIBRARY

const WORD SUSI_VER_MJ = 1;
const WORD SUSI_VER_MR = 1;
//const TCHAR Susi_BUILD_NO[] = _T("061003");

// Error codes for Susi
#define ERR_SUSI_LIB_INIT_FAIL				    -10
#define ERR_SUSI_DRIVER_CONTROL_FAIL			-11
#define ERR_SUSI_LIB_INVALID_PARAMETER		-12
#define ERR_SUSI_BRIGHT_CONTROL_FAIL			-50
#define ERR_SUSI_BRIGHT_OUT_OF_RANGE			-51

// Hardware Monitoring Flags
//*******************************************************
//Voltage
//*******************************************************
#define VCORE	(1<<0)	// Vcore
#define V25		(1<<1)	// 2.5V
#define V33		(1<<2)	// 3.3V
#define V50		(1<<3)	// 5V
#define V120	(1<<4)	// 12V
#define VSB		(1<<5)	// Voltage of standby
#define VBAT	(1<<6)	// VBAT
#define VN50	(1<<7)	// -5V
#define VN120	(1<<8)	// -12V
#define VTT		(1<<9)	// VTT
//*******************************************************
//Temperature
//*******************************************************
#define TCPU	(1<<0)	// CPU temperature
#define TSYS	(1<<1)	// System temperature
//*******************************************************
//Fan Speed
//*******************************************************
#define FCPU	(1<<0)	// CPU FAN Speed
#define FSYS	(1<<1)	// System FAN Speed
#define F2ND	(1<<2)	// Other FAN Speed


void SusiGetVersion(WORD *major, WORD *minor);
BOOL SusiInit(void);
BOOL SusiUnInit(void);
BOOL SusiWDAvailable(void);
BOOL SusiWDGetRange(DWORD *minimum, DWORD *maximum, DWORD *stepping);
BOOL SusiWDSetConfig(DWORD delay, DWORD timeout);
BOOL SusiWDTrigger(void);
BOOL SusiWDDisable(void);
BOOL SusiIOAvailable(void);
BOOL SusiIOInitial(DWORD statuses);
BOOL SusiIOCount(WORD *inCount, WORD *outCount);
BOOL SusiIORead(BYTE pin, BOOL *status);
BOOL SusiIOReadMulti(DWORD pins, DWORD *statuses);
BOOL SusiIOWrite(BYTE pin, BOOL status);
BOOL SusiIOWriteMulti(DWORD pins, DWORD statuses);
BOOL SusiSMBusAvailable(void);
BOOL SusiSMBusReadByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE *Result);
BOOL SusiSMBusReadByteMulti(BYTE SlaveAddress,BYTE RegisterOffset, BYTE *Result, BYTE ByteCount);
BOOL SusiSMBusReadWord(BYTE SlaveAddress, BYTE RegisterOffset, WORD *Result);
BOOL SusiSMBusWriteByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE Result);
BOOL SusiSMBusWriteByteMulti(BYTE SlaveAddress,BYTE RegisterOffset, BYTE *Result, BYTE ByteCount);
BOOL SusiSMBusWriteWord(BYTE SlaveAddress, BYTE RegisterOffset, WORD Result);
BOOL SusiIICAvailable(void);
BOOL SusiIICReadByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE *Result);
BOOL SusiIICWriteByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE Result);
BOOL SusiIICWriteReadCombine(BYTE SlaveAddress, BYTE *WriteBuf, DWORD WriteLen, BYTE *ReadBuf, DWORD ReadLen);
BOOL SusiIICReadByteMulti(BYTE SlaveAddress, BYTE *ReadBuf, DWORD ReadLen);
BOOL SusiIICWriteByteMulti(BYTE SlaveAddress, BYTE *WriteBuf, DWORD WriteLen);
int SusiGetPlatformName(TCHAR *PlatformName, BYTE size);
int SusiGetBIOSVersion(TCHAR *BIOSVersion, BYTE size);
BOOL SusiScreenOn();
BOOL SusiScreenOff();
int SusiVCAvailable(void);
int SusiVCScreenOn();
int SusiVCScreenOff();
int SusiVCGetBright(BYTE *brightness);
int SusiVCSetBright(BYTE brightness);
int SusiVCGetBrightRange(BYTE *minimum, BYTE *maximum, BYTE *stepping);
int SusiHWMAvailable();
int SusiHWMGetTemperature(WORD HWMtype, float *retval, WORD* typesupport = NULL);
int SusiHWMGetFanSpeed(WORD HWMtype, WORD *retval, WORD* typesupport = NULL);
int SusiHWMGetVoltage(DWORD HWMtype, float *retval, DWORD* typesupport = NULL);

BOOL AdvLibGetBuildNO(TCHAR *BuildNO);
void AdvLibGetVersion(WORD *major, WORD *minor);
BOOL AdvLibInit(void);
BOOL AdvLibUnInit(void);
BOOL AdvLibWDAvailable(void);
BOOL AdvLibWDGetRange(DWORD *minimum, DWORD *maximum, DWORD *stepping);
BOOL AdvLibWDSetConfig(DWORD delay, DWORD timeout);
BOOL AdvLibWDTrigger(void);
BOOL AdvLibWDDisable(void);
BOOL AdvLibIOAvailable(void);
BOOL AdvLibIOInitial(DWORD statuses);
BOOL AdvLibIOCount(WORD *inCount, WORD *outCount);
BOOL AdvLibIORead(BYTE pin, BOOL *status);
BOOL AdvLibIOReadMulti(DWORD pins, DWORD *statuses);
BOOL AdvLibIOWrite(BYTE pin, BOOL status);
BOOL AdvLibIOWriteMulti(DWORD pins, DWORD statuses);
BOOL AdvLibSMBusAvailable(void);
BOOL AdvLibSMBusReadByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE *Result);
BOOL AdvLibSMBusReadByteMulti(BYTE SlaveAddress,BYTE RegisterOffset, BYTE *Result, BYTE ByteCount);
BOOL AdvLibSMBusReadWord(BYTE SlaveAddress, BYTE RegisterOffset, WORD *Result);
BOOL AdvLibSMBusWriteByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE Result);
BOOL AdvLibSMBusWriteByteMulti(BYTE SlaveAddress,BYTE RegisterOffset, BYTE *Result, BYTE ByteCount);
BOOL AdvLibSMBusWriteWord(BYTE SlaveAddress, BYTE RegisterOffset, WORD Result);
BOOL AdvLibIICAvailable(void);
BOOL AdvLibIICReadByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE *Result);
BOOL AdvLibIICWriteByte(BYTE SlaveAddress, BYTE RegisterOffset, BYTE Result);
int AdvLibGetPlatformName(TCHAR *PlatformName, BYTE size);
int AdvLibGetBIOSVersion(TCHAR *BIOSVersion, BYTE size);
BOOL AdvLibScreenOn();
BOOL AdvLibScreenOff();
int AdvLibVCAvailable(void);
int AdvLibVCScreenOn();
int AdvLibVCScreenOff();
int AdvLibVCGetBright(BYTE *brightness);
int AdvLibVCSetBright(BYTE brightness);
int AdvLibVCGetBrightRange(BYTE *minimum, BYTE *maximum, BYTE *stepping);
int AdvLibHWMAvailable();
int AdvLibHWMGetTemperature(WORD HWMtype, float *retval, WORD* typesupport = NULL);
int AdvLibHWMGetFanSpeed(WORD HWMtype, WORD *retval, WORD* typesupport = NULL);
int AdvLibHWMGetVoltage(DWORD HWMtype, float *retval, DWORD* typesupport = NULL);
//int AdvLibHWMInit();

#endif //SUSI_LIBRARY
