/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	PAGEGPIO.cpp

Abstract:
	Implementation file for tab page GPIO
	

Revision History:
---------------------------------------------
	May 18, 2006	Change to Susi v1.0

---------------------------------------------
	June 22, 2005	First release
	
---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "PAGEGPIO.h"
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CPAGEGPIO property page

IMPLEMENT_DYNCREATE(CPAGEGPIO, CPropertyPage)

CPAGEGPIO::CPAGEGPIO() : CPropertyPage(CPAGEGPIO::IDD)
{
	//{{AFX_DATA_INIT(CPAGEGPIO)
	m_GPIO_Result = _T("0x0");
	m_GPIO_MultiPinNum = _T("0x0");
	m_GPIOMODE = 0;
	m_GPIO_SinglePinNum = 0;
	m_GPIO_INUM = 0;
	m_GPIO_OUTNUM = 0;
	//}}AFX_DATA_INIT
}

CPAGEGPIO::~CPAGEGPIO()
{
}

void CPAGEGPIO::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPAGEGPIO)
	DDX_Control(pDX, IDC_GPIO_SINGNUM, m_GPIO_SinglePinNumCtrl);
	DDX_Control(pDX, IDC_WRITE, m_GPIO_WriteCtrl);
	DDX_Control(pDX, IDC_READ, m_GPIO_ReadCtrl);
	DDX_Control(pDX, IDC_GPIO_MULTINUM, m_GPIO_MultiPinNumCtrl);
	DDX_Text(pDX, IDC_GPIO_RESULT, m_GPIO_Result);
	DDX_Text(pDX, IDC_GPIO_MULTINUM, m_GPIO_MultiPinNum);
	DDX_Radio(pDX, IDC_RAD_SINGLE_PIN, m_GPIOMODE);
	DDX_Text(pDX, IDC_GPIO_SINGNUM, m_GPIO_SinglePinNum);
	DDX_Text(pDX, IDC_GPIO_INUM, m_GPIO_INUM);
	DDX_Text(pDX, IDC_GPIO_OUTUM, m_GPIO_OUTNUM);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPAGEGPIO, CPropertyPage)
	//{{AFX_MSG_MAP(CPAGEGPIO)
	ON_BN_CLICKED(IDC_READ, OnRead)
	ON_BN_CLICKED(IDC_RAD_SINGLE_PIN, OnRadSinglePin)
	ON_BN_CLICKED(IDC_RAD_MULTI_PIN, OnRadMultiPin)
	ON_WM_CLOSE()
	ON_BN_CLICKED(IDC_WRITE, OnWrite)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPAGEGPIO message handlers

BOOL CPAGEGPIO::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	// TODO: Add extra initialization here
	WORD inCount, outCount;

	UpdateData(TRUE);
	m_GPIO_MultiPinNumCtrl.EnableWindow(FALSE);
	m_GPIO_SinglePinNumCtrl.EnableWindow(TRUE);
	m_GPIO_Result = _T("");

	if(!SusiIOCount(&inCount, &outCount))	// Get the number of GPIO pins 
		AfxMessageBox(_T("Cannot Get the number of GPIO pins!"));
	else{
		m_GPIO_INUM = inCount;
		m_GPIO_OUTNUM = outCount;
	}

	UpdateData(FALSE);
		

	if(!SusiIOInitial(0)){	// Please init the GPIO output first, 
									// otherwise you cannot write GPIO output pins later.
		AfxMessageBox(_T("Init the GPIO output pins failed!"));
		return FALSE;

	}else{
		return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
	}
}


void CPAGEGPIO::OnOK() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));
	
	CPropertyPage::OnOK();
}

void CPAGEGPIO::OnCancel() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));

	CPropertyPage::OnCancel();
}

void CPAGEGPIO::OnRead() 
{
	// TODO: Add your control notification handler code here

	UpdateData(TRUE);
	m_GPIO_Result = _T("");
	UpdateData(FALSE);

	if(!m_GPIOMODE){	// Read a single GPIO pin

		BOOL Result = 0;
	
		UpdateData(TRUE);
		if(!SusiIOAvailable()){

			AfxMessageBox(_T("This platform don't support GPIO"));
	
		}else if(!SusiIORead(m_GPIO_SinglePinNum, &Result)){
		
			AfxMessageBox(_T("GPIO Read Failed"));

		}else{

			TCHAR temp[3];
			CString output;

			_itot(Result, temp, 16);
			output = _T("0x");
			output.Insert(output.GetLength(), temp);
			m_GPIO_Result = m_GPIO_Result + output;
		}

		UpdateData(FALSE);

	}else{	// Read multiple GPIO pins

		DWORD PinNum;
		char *p;
		DWORD Result = 0;

		PinNum = strtol(m_GPIO_MultiPinNum, &p, 16);
	
		UpdateData(TRUE);
		if(!SusiIOAvailable()){

			AfxMessageBox(_T("This platform don't support GPIO"));
	
		}else if(!SusiIOReadMulti(PinNum, &Result)){
		
			AfxMessageBox(_T("GPIO Read Multi Failed"));

		}else{

			TCHAR temp[3];
			CString output;

			_itot(Result, temp, 16);
			output = _T("0x");
			output.Insert(output.GetLength(), temp);
			m_GPIO_Result = m_GPIO_Result + output;
		}

		UpdateData(FALSE);

	}	
	
}

void CPAGEGPIO::OnRadSinglePin() 
{
	// TODO: Add your control notification handler code here

	UpdateData(TRUE);
	m_GPIO_MultiPinNumCtrl.EnableWindow(FALSE);
	m_GPIO_SinglePinNumCtrl.EnableWindow(TRUE);
	m_GPIO_Result = _T("");
	UpdateData(FALSE);
	
}

void CPAGEGPIO::OnRadMultiPin() 
{
	// TODO: Add your control notification handler code here

	UpdateData(TRUE);
	m_GPIO_SinglePinNumCtrl.EnableWindow(FALSE);
	m_GPIO_MultiPinNumCtrl.EnableWindow(TRUE);
	m_GPIO_Result = _T("");
	UpdateData(FALSE);
	
}

void CPAGEGPIO::OnWrite() 
{
	// Please make sure of the function SusiIOInitial(...) has been called before,
	// otherwise you cannot write any GPIO output pin here.
	// In this sample, I have called the function SusiIOInitial(...) within the function OnInitDialog().
	// Please refer to Susi document for more detail about GPIO access.
	
	UpdateData(TRUE);

	if(!m_GPIOMODE){	// Write a single GPIO pin

		char *p;		
		BYTE Result = (BYTE)strtol(m_GPIO_Result, &p, 16);
	
		if(!SusiIOAvailable()){

			AfxMessageBox(_T("This platform don't support GPIO"));
	
		}else if(!SusiIOWrite(m_GPIO_SinglePinNum, Result)){
		
			AfxMessageBox(_T("GPIO Write Failed"));

		}else{
			AfxMessageBox(_T("Write a single GPIO pin successfully!"));
		}

	}else{	// Write multiple GPIO pins

		
		char *p;
		DWORD PinNum = strtol(m_GPIO_MultiPinNum, &p, 16);
		DWORD Result = strtol(m_GPIO_Result, &p, 16);
		
		if(!SusiIOAvailable()){

			AfxMessageBox(_T("This platform don't support GPIO"));
	
		}else if(!SusiIOWriteMulti(PinNum, Result)){
		
			AfxMessageBox(_T("GPIO Write Multi Failed"));

		}else{
			AfxMessageBox(_T("Write mutiple GPIO pins successfully!"));
		}

	}

	UpdateData(FALSE);
}
