/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	PAGEMultiIIC.cpp

Abstract:
	Implementation file for tab page Multi IIC
	

Revision History:
---------------------------------------------
	July 19, 2006	First release for Susi v1.0

---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "PAGEMultiIIC.h"
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CPAGEMultiIIC property page

IMPLEMENT_DYNCREATE(CPAGEMultiIIC, CPropertyPage)

CPAGEMultiIIC::CPAGEMultiIIC() : CPropertyPage(CPAGEMultiIIC::IDD)
{
	//{{AFX_DATA_INIT(CPAGEMultiIIC)
	m_SADDR = _T("");
	m_INDATA = _T("");
	m_RESULT = _T("");
	m_READNUM = 0;
	m_WRITENUM = 0;
	//}}AFX_DATA_INIT
}

CPAGEMultiIIC::~CPAGEMultiIIC()
{
}

void CPAGEMultiIIC::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPAGEMultiIIC)
	DDX_Text(pDX, IDC_SADDR, m_SADDR);
	DDX_Text(pDX, IDC_INDATA, m_INDATA);
	DDX_Text(pDX, IDC_RESULT, m_RESULT);
	DDX_Text(pDX, IDC_READNUM, m_READNUM);
	DDX_Text(pDX, IDC_WRITENUM, m_WRITENUM);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPAGEMultiIIC, CPropertyPage)
	//{{AFX_MSG_MAP(CPAGEMultiIIC)
	ON_BN_CLICKED(IDC_READ_MULTI_BYTES, OnReadMultiBytes)
	ON_BN_CLICKED(IDC_WRITE_MULTI_BYTE, OnWriteMultiByte)
	ON_BN_CLICKED(IDC_WRITE_READ, OnWriteRead)
	ON_EN_CHANGE(IDC_INDATA, OnChangeIndata)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPAGEMultiIIC message handlers

void CPAGEMultiIIC::OnReadMultiBytes() 
{
	// TODO: Add your control notification handler code here
	//BYTE Address, Register, Result=0;
	BYTE Address, *Result;
	char *p;
	UpdateData(TRUE);

	Result = new BYTE[m_READNUM];

	Address = (BYTE)strtol(m_SADDR, &p, 16);

	// Read data from the device through IIC
	if(!SusiIICAvailable()){
		m_RESULT = "This platform don't support IIC function";
	
	}else if(!SusiIICReadByteMulti(Address, Result, m_READNUM)){
		m_RESULT = "IIC Read failed";
	
	}else{
		TCHAR temp[1];

		m_RESULT.Empty();

		for(DWORD i=0; i<m_READNUM; i++)
		{
			_itot(Result[i], temp, 16);
			m_RESULT = m_RESULT + temp;
			m_RESULT = m_RESULT + _T(" ");

		}
		}
	delete []Result;
	UpdateData(FALSE);
}

void CPAGEMultiIIC::OnWriteMultiByte() 
{
	// TODO: Add your control notification handler code here
	BYTE Address, *Result;
	char *p;
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	
	// Look for all data demanded to write via IIC
	int pos1 = 0, pos2 = 0;
	Result = new BYTE[m_WRITENUM];

	for(DWORD i=0; i< m_WRITENUM; i++)
	{
		pos2 = m_INDATA.Find(' ', pos1); // There is a space follows each data
		
		if(pos1 != pos2 + 1 && pos2 != -1) // If the space exists...
		{
			Result[i] = (BYTE)strtol(m_INDATA.Mid(pos1, pos2-pos1), &p, 16); // Get the data 
			pos1 = pos2 + 1; // set the starting position to look for the next data

		}else if(pos2 == -1){
			pos2 = m_INDATA.Find('\0', pos1); // Look for the last data
			Result[i] = (BYTE)strtol(m_INDATA.Mid(pos1, pos2-pos1), &p, 16); // Get the data			
		}

	}

	// Write multiple bytes via IIC
	if(!SusiIICAvailable()){
		m_RESULT = "This platform don't support IIC Write Byte Mode";
			
	}else if(!SusiIICWriteByteMulti(Address, Result, m_WRITENUM)){
		m_RESULT = "IIC Write failed";
	}else
		m_RESULT = "IIC Write successful";

	delete []Result;

	UpdateData(FALSE);
}

void CPAGEMultiIIC::OnWriteRead() 
{
	// TODO: Add your control notification handler code here
	BYTE Address, *Write_Result, *Read_Result;
	char *p;
	
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	
	// Look for all data demanded to write via IIC
	int pos1 = 0, pos2 = 0;
	Write_Result = new BYTE[m_WRITENUM];
	Read_Result = new BYTE[m_READNUM];

	for(DWORD i=0; i< m_WRITENUM; i++)
	{
		pos2 = m_INDATA.Find(' ', pos1); // There is a space follows each data
		
		if(pos1 != pos2 + 1 && pos2 != -1) // If the space exists...
		{
			Write_Result[i] = (BYTE)strtol(m_INDATA.Mid(pos1, pos2-pos1), &p, 16); // Get the data 
			pos1 = pos2 + 1; // set the starting position to look for the next data

		}else if(pos2 == -1){
			pos2 = m_INDATA.Find('\0', pos1); // Look for the last data
			Write_Result[i] = (BYTE)strtol(m_INDATA.Mid(pos1, pos2-pos1), &p, 16); // Get the data			
		}

	}

	// Read/Write multiple bytes via IIC
	if(!SusiIICAvailable()){
		m_RESULT = "This platform don't support IIC Write Mode";			
	}else if(!SusiIICWriteReadCombine(Address, Write_Result, m_WRITENUM, Read_Result, m_READNUM)){
		m_RESULT = "IIC Read/Write Combine failed";
	}else{
		TCHAR temp[1];

		m_RESULT.Empty();

		for(DWORD i=0; i<m_READNUM; i++)
		{
			_itot(Read_Result[i], temp, 16);
			m_RESULT = m_RESULT + temp;
			m_RESULT = m_RESULT + _T(" ");
		}
	}
	delete []Read_Result;
	delete []Write_Result;

	UpdateData(FALSE);
}

void CPAGEMultiIIC::OnOK() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));

	CPropertyPage::OnOK();
}

void CPAGEMultiIIC::OnCancel() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));

	CPropertyPage::OnCancel();
}

void CPAGEMultiIIC::OnChangeIndata() 
{
	// TODO: Add your control notification handler code here
	
	char *InBuffer;
	InBuffer = new char[1000];

	m_WRITENUM = 1;

	if(!GetDlgItemText(IDC_INDATA, InBuffer, 1000))
		SetDlgItemInt( IDC_WRITENUM, 0, TRUE );
	else{
		for(DWORD i=0; i< strlen(InBuffer)-1; i++)
		{
			if(InBuffer[i] == ' ' && InBuffer[i+1] != ' ')
				m_WRITENUM++;
		}
		
		SetDlgItemInt( IDC_WRITENUM, m_WRITENUM, TRUE );
	}

	delete []InBuffer;
}
