/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	PAGESMBUS.cpp

Abstract:
	Implementation file for tab page SMBus
	

Revision History:
---------------------------------------------
	May 18, 2006	Change to Susi v1.0

---------------------------------------------
	June 22, 2005	First release
	
---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "PAGESMBUS.h"
#include <String>
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define DATA_READ	0	// Read data
#define DATA_WRITE	1	// Write data

/////////////////////////////////////////////////////////////////////////////
// CPAGESMBUS property page

IMPLEMENT_DYNCREATE(CPAGESMBUS, CPropertyPage)

CPAGESMBUS::CPAGESMBUS() : CPropertyPage(CPAGESMBUS::IDD)
{
	//{{AFX_DATA_INIT(CPAGESMBUS)
	m_BYTENUM = 0;
	m_REGOFFSET = _T("0x0");
	m_SADDR = _T("0x0");
	m_RESULT = _T("0x0");
	m_AccMode = 0;
	//}}AFX_DATA_INIT
}

CPAGESMBUS::~CPAGESMBUS()
{
}

void CPAGESMBUS::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPAGESMBUS)
	DDX_Control(pDX, IDC_BYTENUM, m_BYTENUMCTRL);
	DDX_Control(pDX, IDC_READ, m_READ);
	DDX_Control(pDX, IDC_WRITE, m_WRITE);
	DDX_Text(pDX, IDC_BYTENUM, m_BYTENUM);
	DDX_Text(pDX, IDC_REGOFFSET, m_REGOFFSET);
	DDX_Text(pDX, IDC_SADDR, m_SADDR);
	DDX_Text(pDX, IDC_RESULT, m_RESULT);
	DDX_Radio(pDX, IDC_RAD_BYTE, m_AccMode);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPAGESMBUS, CPropertyPage)
	//{{AFX_MSG_MAP(CPAGESMBUS)
	ON_BN_CLICKED(IDC_RAD_BYTE, OnRadByte)
	ON_BN_CLICKED(IDC_RAD_MULTIBYTE, OnRadMultibyte)
	ON_BN_CLICKED(IDC_RAD_WORD, OnRadWord)
	ON_BN_CLICKED(IDC_READ, OnRead)
	ON_BN_CLICKED(IDC_WRITE, OnWrite)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPAGESMBUS message handlers

BOOL CPAGESMBUS::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	// TODO: Add extra initialization here

	m_BYTENUMCTRL.EnableWindow(FALSE);
	UpdateData(FALSE);
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CPAGESMBUS::OnCancel() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));
	
	CPropertyPage::OnCancel();
}

void CPAGESMBUS::OnOK() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));

	CPropertyPage::OnOK();
}


void CPAGESMBUS::OnRadByte() 
{
	// TODO: Add your control notification handler code here
	UpdateData(TRUE);
	m_BYTENUMCTRL.EnableWindow(FALSE);
	m_RESULT = _T("");
	UpdateData(FALSE);	
}

void CPAGESMBUS::OnRadMultibyte() 
{
	// TODO: Add your control notification handler code here
	UpdateData(TRUE);
	m_BYTENUMCTRL.EnableWindow(TRUE);
	m_RESULT = _T("");
	UpdateData(FALSE);	
	
}

void CPAGESMBUS::OnRadWord() 
{
	// TODO: Add your control notification handler code here
	UpdateData(TRUE);
	m_BYTENUMCTRL.EnableWindow(FALSE);
	m_RESULT = _T("");
	UpdateData(FALSE);	
	
}

void CPAGESMBUS::OnRead() 
{
	// TODO: Add your control notification handler code here
	UpdateData(TRUE);
	m_RESULT = _T("");
	UpdateData(FALSE);

	switch(m_AccMode)
	{
	case 0:
		ReadByteMode();
		break;
	case 1:
		ReadMultiByteMode();
		break;
	case 2:
		ReadWordMode();
		break;

	}
	
}

void CPAGESMBUS::OnWrite() 
{
	// TODO: Add your control notification handler code here

	switch(m_AccMode)
	{
	case 0:
		WriteByteMode();
		break;
	case 1:
		WriteMultiByteMode();
		break;
	case 2:
		WriteWordMode();
		break;

	}

}

/*
////////////////////////////////////////////////////

  R/W a byte data

////////////////////////////////////////////////////
*/

void CPAGESMBUS::ReadByteMode()
{
	BYTE Address, Register, Result=0;
	char *p;
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);

	// Read data from the device through SMBus
	if(!SusiSMBusAvailable()){
		AfxMessageBox(_T("This platform don't support SMBus Write Byte"));
	
	}else if(!SusiSMBusReadByte(Address, Register, &Result)){
		AfxMessageBox(_T("SMBus Read Byte failed"));
	
	}else{
		
		TCHAR temp[3];
		CString output;

		_itot(Result, temp, 16);
		output = _T("0x");
		output.Insert(output.GetLength(), temp);
		m_RESULT = m_RESULT + output;

		UpdateData(FALSE);
	}
	
}

void CPAGESMBUS::WriteByteMode()
{
	// TODO: Add your control notification handler code here
	BYTE Address, Register, Result;
	char *p;
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);
	Result = (BYTE)strtol(m_RESULT, &p, 16);

	// Write data to the device through SMBus
	if(!SusiSMBusAvailable())
	{
		AfxMessageBox(_T("This platform don't support SMBus Write Byte"));
	}
	else if(!SusiSMBusWriteByte(Address, Register, Result))
	{
		AfxMessageBox(_T("SMBus Write Byte failed"));
	}

}

/*
////////////////////////////////////////////////////

  R/W multiple bytes data

////////////////////////////////////////////////////
*/

void CPAGESMBUS::ReadMultiByteMode()
{
	BYTE Address, Register, *Result;
	char *p;
	UpdateData(TRUE);

	Result = new BYTE[m_BYTENUM];

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);

	// Read data from the device through SMBus
	if(!SusiSMBusAvailable()){
		AfxMessageBox(_T("This platform don't support SMBus Write Byte Mode"));
	
	}else if(!SusiSMBusReadByteMulti(Address, Register, Result, m_BYTENUM)){
		AfxMessageBox(_T("SMBus Read Byte failed"));	
	
	}else{
		
		TCHAR temp[3];
		CString output;

		for(int i=0; i<m_BYTENUM; i++)
		{
			_itot(Result[i], temp, 16);
			output = _T("0x");
			output.Insert(output.GetLength(), temp);
			
			if(i == m_BYTENUM - 1) // The last data do not need comma
				m_RESULT = m_RESULT + output;
			else
				m_RESULT = m_RESULT + output + ",";
		}

		delete []Result;
		UpdateData(FALSE);
	}
	
}

void CPAGESMBUS::WriteMultiByteMode()
{

	// TODO: Add your control notification handler code here
	BYTE Address, Register, *Result;
	char *p;
	
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);
	
	// Look for all data demanded to write via SMBus
	int pos1 = 0, pos2 = 0;
	Result = new BYTE[m_BYTENUM];

	for(int i=0; i< m_BYTENUM; i++)
	{
		pos2 = m_RESULT.Find(',', pos1); // There is a comma follows each data
		
		if(pos1 != pos2 + 1 && pos2 != -1) // If the comma exists...
		{
			Result[i] = (BYTE)strtol(m_RESULT.Mid(pos1, pos2-pos1), &p, 16); // Get the data 
			pos1 = pos2 + 1; // set the starting position to look for the next data

		}else if(pos2 == -1){
			pos2 = m_RESULT.Find('\0', pos1); // Look for the last data
			Result[i] = (BYTE)strtol(m_RESULT.Mid(pos1, pos2-pos1), &p, 16); // Get the data			
		}

	}

	// Write multiple bytes via SMBus
	if(!SusiSMBusAvailable()){
		AfxMessageBox(_T("This platform don't support SMBus Write Byte Mode"));
			
	}else if(!SusiSMBusWriteByteMulti(Address, Register, Result, m_BYTENUM)){
		AfxMessageBox(_T("SMBus Write Byte failed"));
	}

	delete []Result;

		
}

/*
////////////////////////////////////////////////////

  R/W a word data

////////////////////////////////////////////////////
*/

void CPAGESMBUS::ReadWordMode()
{
	// TODO: Add your control notification handler code here
	BYTE Address, Register;
	WORD Result = 0;
	char *p;
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);

	// Read data from the device through SMBus
	if(!SusiSMBusAvailable()){
		AfxMessageBox(_T("This platform don't support SMBus Write Byte"));
	
	}else if(!SusiSMBusReadWord(Address, Register, &Result)){
		AfxMessageBox(_T("SMBus Read Word failed"));
	
	}else{
		
		TCHAR temp[6];
		CString output;

		_itot(Result, temp, 16);
		output = _T("0x");
		output.Insert(output.GetLength(), temp);
		m_RESULT = m_RESULT + output;

		UpdateData(FALSE);
	}
}


void CPAGESMBUS::WriteWordMode()
{
	// TODO: Add your control notification handler code here
	BYTE Address, Register;
	WORD Result;
	char *p;
	UpdateData(TRUE);

	Address = (BYTE)strtol(m_SADDR, &p, 16);
	Register = (BYTE)strtol(m_REGOFFSET, &p, 16);
	Result = (WORD)strtol(m_RESULT, &p, 16);

	// Write data to the device through SMBus
	if(!SusiSMBusAvailable()){

		AfxMessageBox(_T("This platform don't support SMBus Write Word Mode"));

	}else if(!SusiSMBusWriteWord(Address, Register, Result)){

		AfxMessageBox(_T("SMBus Write Word failed"));
	}
}
