/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	PAGEVCTRL.cpp

Abstract:
	Implementation file for tab page VGA CONTROL
	

Revision History:
---------------------------------------------
	May 18, 2006	Change to Susi v1.0

---------------------------------------------
	June 22, 2005	First release
	
---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "PAGEVCTRL.h"
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

BYTE minimum = 0;
BYTE maximum = 0;
BYTE stepping = 0;

/////////////////////////////////////////////////////////////////////////////
// CPAGEVCTRL property page

IMPLEMENT_DYNCREATE(CPAGEVCTRL, CPropertyPage)

CPAGEVCTRL::CPAGEVCTRL() : CPropertyPage(CPAGEVCTRL::IDD)
{
	//{{AFX_DATA_INIT(CPAGEVCTRL)
	m_RAD_VGASwitch = 0;
	m_BRIGSLIDER_VAL = 0;
	m_BRIGHTVAL = 0;
	//}}AFX_DATA_INIT
}

CPAGEVCTRL::~CPAGEVCTRL()
{
}

void CPAGEVCTRL::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPAGEVCTRL)
	DDX_Control(pDX, IDC_RAD_VGAON, m_RAD_VGASwitchCtrl);
	DDX_Control(pDX, IDC_BRIGSLIDER, m_BRIGSLIDER_CTRL);
	DDX_Control(pDX, IDC_BRIGUP, m_BRIGHTUP);
	DDX_Control(pDX, IDC_BRIGDOWN, m_BRIGDOWN);
	DDX_Radio(pDX, IDC_RAD_VGAON, m_RAD_VGASwitch);
	DDX_Slider(pDX, IDC_BRIGSLIDER, m_BRIGSLIDER_VAL);
	DDX_Text(pDX, IDC_BRIGVAL, m_BRIGHTVAL);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPAGEVCTRL, CPropertyPage)
	//{{AFX_MSG_MAP(CPAGEVCTRL)
	ON_BN_CLICKED(IDC_RAD_VGAON, OnRadVgaon)
	ON_BN_CLICKED(IDC_RAD_VGAOFF, OnRadVgaoff)
	ON_BN_CLICKED(IDC_BRIGUP, OnBrigup)
	ON_BN_CLICKED(IDC_BRIGDOWN, OnBrigdown)
	ON_WM_VSCROLL()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPAGEVCTRL message handlers

BOOL CPAGEVCTRL::OnInitDialog() 
{
	BYTE Status = 0;

	CPropertyPage::OnInitDialog();
	
	// TODO: Add extra initialization here


	
	if(SusiVCGetBrightRange(&minimum, &maximum, &stepping)<0){	// Get the range of brightness
		AfxMessageBox(_T("Cannot get the brightness range!"));
		return FALSE;
	
	}else if(SusiVCGetBright(&Status)<0){	// Get the current brightness 
		AfxMessageBox(_T("SusiVCGetBright function failed!"));
		return FALSE;
	
	}else{	// Set the slider controler
		m_BRIGSLIDER_CTRL.SetRange(minimum, maximum);
		m_BRIGSLIDER_CTRL.SetTicFreq(stepping*25);
		UpdateData(TRUE);
		m_BRIGHTVAL = Status;
		UpdateData(FALSE);
		m_BRIGSLIDER_CTRL.SetPos(maximum - Status);
		//CString str;

		//str.Format(_T("minimum=%d, maximum=%d, stepping=%d, Status=%d\n"), minimum,maximum,stepping,Status);
		//AfxMessageBox(str);
			
		return TRUE;  // return TRUE  unless you set the focus to a control

	}
}

void CPAGEVCTRL::OnCancel() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));
	//else
		//AfxMessageBox(_T("Susi uninitialize success !"));

	CPropertyPage::OnCancel();
}


void CPAGEVCTRL::OnOK() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));
	//else
		//AfxMessageBox(_T("Susi uninitialize success !"));

	CPropertyPage::OnOK();
}

/*
////////////////////////////////////////////////////

  Screen on/off Control

////////////////////////////////////////////////////
*/

// Turn on the screen
void CPAGEVCTRL::OnRadVgaon() 
{
	// TODO: Add your control notification handler code here
	if(SusiVCScreenOn()<0)
		AfxMessageBox(_T("Cannot turn on the screen!"));
	
}


// Turn off the screen
void CPAGEVCTRL::OnRadVgaoff() 
{
	// TODO: Add your control notification handler code here
	if(SusiVCScreenOff()<0)
		AfxMessageBox(_T("Cannot turn off the screen!"));


}

// Set the hotkey
BOOL CPAGEVCTRL::PreTranslateMessage(MSG* pMsg) 
{
    switch(pMsg->message)
	{
	case WM_KEYDOWN:
       switch (pMsg->wParam) 
	   {
	   case VK_F11: //Press F11 is to turn on the screen"

		   if(SusiVCScreenOn()<0)
				AfxMessageBox(_T("Cannot turn on the screen!"));
		   else
		   {
			   CheckDlgButton(IDC_RAD_VGAON, 1);
			   CheckDlgButton(IDC_RAD_VGAOFF, 0);
		   }

			break;

	   case VK_F12: //Press F12 to turn off the screen"
			
		   if(SusiVCScreenOff()<0)
				AfxMessageBox(_T("Cannot turn off the screen!"));
		   else
		   {
			   CheckDlgButton(IDC_RAD_VGAON, 0);
			   CheckDlgButton(IDC_RAD_VGAOFF, 1);
		   }
 
		   break;
	   default:
			break;
	   }
	   break;


	default:
		break;

	}

    return CDialog::PreTranslateMessage(pMsg);
}

/*
////////////////////////////////////////////////////

  Brightness Control

////////////////////////////////////////////////////
*/

// Press "UP" button to increase the brightness
void CPAGEVCTRL::OnBrigup() 
{
	// TODO: Add your control notification handler code here
	BYTE Status = 0;
	UpdateData(TRUE);

	if(SusiVCGetBright(&Status) < 0)
		AfxMessageBox(_T("SusiVCGetBright function failed!"));

	else if(Status >= maximum)
		AfxMessageBox(_T("It is brightest."));

	else if(SusiVCSetBright(Status + (BYTE)stepping) < 0)
		AfxMessageBox(_T("SusiVCSetBright function failed!"));
	
	else{
		m_BRIGHTVAL = Status + (BYTE)stepping;
		m_BRIGSLIDER_VAL = maximum - m_BRIGHTVAL;
		m_BRIGSLIDER_CTRL.SetPos(maximum - m_BRIGHTVAL);
	}

	UpdateData(FALSE);
	
}

// Press "DOWN" button to decrease the brightness
void CPAGEVCTRL::OnBrigdown() 
{
	// TODO: Add your control notification handler code here
	BYTE Status = 0;
	UpdateData(TRUE);

	if(SusiVCGetBright(&Status) < 0)
		AfxMessageBox(_T("SusiVCGetBright function failed!"));

	else if(Status <= minimum)
		AfxMessageBox(_T("It is the darkest!"));

	else if(SusiVCSetBright(Status - (BYTE)stepping) < 0)
		AfxMessageBox(_T("SusiVCSetBright function failed!"));
	
	else{
		m_BRIGHTVAL = Status - (BYTE)stepping;
		m_BRIGSLIDER_VAL = maximum - m_BRIGHTVAL;
		m_BRIGSLIDER_CTRL.SetPos(maximum - m_BRIGHTVAL);
	}

	UpdateData(FALSE);
	
}

//SLIDER Control
void CPAGEVCTRL::OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar) 
{
	// TODO: Add your message handler code here and/or call default
	UpdateData(TRUE);
	m_BRIGHTVAL = maximum - m_BRIGSLIDER_CTRL.GetPos();
	UpdateData(FALSE);
	
	if(SusiVCSetBright(m_BRIGHTVAL)<0)
		AfxMessageBox(_T("SusiVCSetBright function failed!"));
	
	CDialog::OnVScroll(nSBCode, nPos, pScrollBar);
}
