/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	PAGEWDT.cpp

Abstract:
	Implementation file for tab page WATCHDOG
	

Revision History:
---------------------------------------------
	May 18, 2006	Change to Susi v1.0

---------------------------------------------
	June 22, 2005	First release
	
---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "PAGEWDT.h"
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define	TimerID 122

/////////////////////////////////////////////////////////////////////////////
// CPAGEWDT property page

IMPLEMENT_DYNCREATE(CPAGEWDT, CPropertyPage)

CPAGEWDT::CPAGEWDT() : CPropertyPage(CPAGEWDT::IDD)
{
	//{{AFX_DATA_INIT(CPAGEWDT)
	m_WDTCDOWN = 0;
	m_WDTDELAY = 0;
	m_WDTMOUT = 0;
	m_WDTMAX = 0;
	m_WDTMIN = 0;
	m_WDTSTEP = 0;
	//}}AFX_DATA_INIT
}

CPAGEWDT::~CPAGEWDT()
{
}

void CPAGEWDT::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPAGEWDT)
	DDX_Control(pDX, IDC_DELAY, m_WDTDELAYCTRL);
	DDX_Control(pDX, IDC_TIMEOUT, m_WDTMOUTCTRL);
	DDX_Control(pDX, IDC_STOP, m_WDTSTOP);
	DDX_Control(pDX, IDC_START, m_WDTSTART);
	DDX_Control(pDX, IDC_REFRESH, m_WDTREF);
	DDX_Text(pDX, IDC_COUNTDOWN, m_WDTCDOWN);
	DDX_Text(pDX, IDC_DELAY, m_WDTDELAY);
	DDX_Text(pDX, IDC_TIMEOUT, m_WDTMOUT);
	DDX_Text(pDX, IDC_MAX, m_WDTMAX);
	DDX_Text(pDX, IDC_MIN, m_WDTMIN);
	DDX_Text(pDX, IDC_STEP, m_WDTSTEP);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CPAGEWDT, CPropertyPage)
	//{{AFX_MSG_MAP(CPAGEWDT)
	ON_BN_CLICKED(IDC_START, OnStart)
	ON_WM_TIMER()
	ON_BN_CLICKED(IDC_REFRESH, OnRefresh)
	ON_BN_CLICKED(IDC_STOP, OnStop)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPAGEWDT message handlers

BOOL CPAGEWDT::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	// TODO: Add extra initialization here

	m_WDTREF.EnableWindow(FALSE);
	m_WDTSTOP.EnableWindow(FALSE);
	SusiWDGetRange(&m_WDTMIN, &m_WDTMAX, &m_WDTSTEP);
	UpdateData(FALSE);
	

	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}


void CPAGEWDT::OnTimer(UINT nIDEvent) 
{
	// TODO: Add your message handler code here and/or call default

	m_WDTCDOWN -= 100;
	UpdateData(FALSE);
	
	CPropertyPage::OnTimer(nIDEvent);
}


void CPAGEWDT::OnStart() 
{
	// TODO: Add your control notification handler code here
	UpdateData(TRUE);
	if(!SusiWDSetConfig(m_WDTDELAY,m_WDTMOUT))
	{
		AfxMessageBox(_T("This platform has no Watchdog or timeout value is invalid!!"));
	}
	else
	{
		m_WDTSTART.EnableWindow(FALSE);
		m_WDTREF.EnableWindow(TRUE);
		m_WDTSTOP.EnableWindow(TRUE);
		m_WDTCDOWN = m_WDTMOUT + m_WDTDELAY;
		m_WDTMOUTCTRL.EnableWindow(FALSE);
		m_WDTDELAYCTRL.EnableWindow(FALSE);
		this->SetTimer(TimerID,100,NULL);
		UpdateData(FALSE);
	}
	
}



void CPAGEWDT::OnRefresh() 
{
	// TODO: Add your control notification handler code here

	if(!SusiWDTrigger())
	{
		AfxMessageBox(_T("Trigger Watchdog failed"));
	}
	else
	{
		m_WDTCDOWN = m_WDTMOUT;
		UpdateData(FALSE);
	}
	
}

void CPAGEWDT::OnStop() 
{
	// TODO: Add your control notification handler code here

	if(!SusiWDDisable())
	{
		AfxMessageBox(_T("Disable Watchdog failed"));
	}
	else
	{
		m_WDTSTART.EnableWindow(TRUE);
		m_WDTREF.EnableWindow(FALSE);
		m_WDTSTOP.EnableWindow(FALSE);
		m_WDTMOUTCTRL.EnableWindow(TRUE);
		m_WDTDELAYCTRL.EnableWindow(TRUE);
		this->KillTimer(TimerID);
	}
	
}




void CPAGEWDT::OnCancel() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));
	
	CPropertyPage::OnCancel();
}

void CPAGEWDT::OnOK() 
{
	// TODO: Add your specialized code here and/or call the base class
	if(!SusiUnInit())
		AfxMessageBox(_T("Susi uninitialize failed !"));

	CPropertyPage::OnOK();
}
