/*++

Copyright (c) Advantech Co., Ltd. All Rights Reserved


File Name:
	SetPage.cpp

Abstract:
	Implementation file for adding tab page
	

Revision History:
---------------------------------------------
	May 18, 2006	Change to Susi v1.0

---------------------------------------------
	June 22, 2005	First release
	
---------------------------------------------

Programmers:
	Baker  Chang

--*/

#include "stdafx.h"
#include "SusiDEMO.h"
#include "SetPage.h"
#include "PAGEWDT.h"
#include "PAGESMBUS.h"
#include "PAGEIIC.h"
#include "PAGEMultiIIC.h"
#include "PAGEVCTRL.h"
#include "PAGEABOUT.h"
#include "Susi.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dialog Data
	//{{AFX_DATA(CAboutDlg)
	enum { IDD = IDD_ABOUTBOX };
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CAboutDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	//{{AFX_MSG(CAboutDlg)
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
	//{{AFX_DATA_INIT(CAboutDlg)
	//}}AFX_DATA_INIT
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CAboutDlg)
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
	//{{AFX_MSG_MAP(CAboutDlg)
		// No message handlers
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSusiFuncSheet

IMPLEMENT_DYNAMIC(CSusiFuncSheet, CPropertySheet)

CSusiFuncSheet::CSusiFuncSheet(UINT nIDCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(nIDCaption, pParentWnd, iSelectPage)
{
	AddControlPages();

	// TODO :: Add the pages for the rest of the controls here.
}

CSusiFuncSheet::CSusiFuncSheet(LPCTSTR pszCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(pszCaption, pParentWnd, iSelectPage)
{
	AddControlPages();
}

CSusiFuncSheet::~CSusiFuncSheet()
{
}

void CSusiFuncSheet::AddControlPages()
{
	m_hIcon = AfxGetApp()->LoadIcon(IDI_ESSD);
	m_psh.dwFlags |= PSP_USEHICON;
	m_psh.dwFlags &= ~PSH_HASHELP;  // Lose the Help button
	m_psh.hIcon = m_hIcon;

	// Add pages here
	if(SusiWDAvailable())		// Detect whether the functions of Watchdog control is available	
		AddPage(&m_pageWDT);

	if(SusiIOAvailable())		// Detect whether the functions of GPIO control is available
		AddPage(&m_pageGPIO);

	if(SusiSMBusAvailable())	// Detect whether the functions of SMBus control is available	
		AddPage(&m_pageSMBus);

	if(SusiIICAvailable())	// Detect whether the functions of IIC control is available
	{
		AddPage(&m_pageIIC);
		AddPage(&m_pageMultiIIC);
	}
	
	if(!SusiVCAvailable())	// Detect whether the functions of brightness control is available
		AddPage(&m_pageVCTRL);

	if(SusiHWMAvailable()==0)
		AddPage(&m_pageHWMNEW);

	AddPage(&m_pageABOUT);

}

BEGIN_MESSAGE_MAP(CSusiFuncSheet, CPropertySheet)
	//{{AFX_MSG_MAP(CSusiFuncSheet)
	ON_WM_QUERYDRAGICON()
	ON_WM_SYSCOMMAND()
	ON_BN_CLICKED(PSBTN_OK, PressButton)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSusiFuncSheet message handlers

BOOL CSusiFuncSheet::OnInitDialog()
{
	// Add "About..." menu item to system menu.

	// IDM_ABOUTBOX must be in the system command range.
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	SetIcon(m_hIcon, TRUE);
	SetIcon(m_hIcon, FALSE);

	// TODO: Add extra initialization here

	return CPropertySheet::OnInitDialog();
}

void CSusiFuncSheet::OnClose() 
{
	// TODO: Add your message handler code here and/or call default

	if(!SusiUnInit())
	{
		AfxMessageBox(_T("Susi uninitialize failed !"));
	}//else{
		//AfxMessageBox(_T("Susi uninitialize success !"));
	//}
}

HCURSOR CSusiFuncSheet::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

BOOL CSusiFuncSheet::Create(LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext)
{
	return CWnd::Create(lpszClassName, lpszWindowName, dwStyle, rect, pParentWnd, nID, pContext);
}

void CSusiFuncSheet::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();

	}else if(nID == SC_CLOSE) {

		if(!SusiUnInit())
			AfxMessageBox(_T("Susi uninitialize failed !"));
		//else
			//AfxMessageBox(_T("Susi uninitialize success !"));
	}

		CPropertySheet::OnSysCommand(nID, lParam);
}


void CSusiFuncSheet::PressButton( int nButton )
{
	if(!SusiUnInit())
	{
		AfxMessageBox(_T("Susi uninitialize failed !"));
	}//else{
		//AfxMessageBox(_T("Susi uninitialize success !"));
	//}

}

// Simulate the selection of OK and Cancel buttons when Alt+K and
// Alt+C are pressed.  CMyPropertySheet is a CPropertySheet-derived 
// class.
BOOL CSusiFuncSheet::PreTranslateMessage(MSG* pMsg) 
{
   if (pMsg->message >= WM_KEYFIRST && pMsg->message <= WM_KEYLAST)
   {
      BOOL altkey = GetKeyState(VK_MENU) < 0;
      if (altkey)
      {
         BOOL handled = TRUE;
         switch(toupper(pMsg->wParam))
         {
         case 'C':                     // for Alt+C - Cancel button
            PressButton(PSBTN_CANCEL);   // or EndDialog(IDCANCEL);
            break;

         case 'K':                     // for Alt+K - OK button
            PressButton(PSBTN_OK);      // or EndDialog(IDOK);
            break;

         default:
            handled = FALSE;
         }

         if (handled)
            return TRUE;
      }
   }

   return CPropertySheet::PreTranslateMessage(pMsg);
}






